import React, {useEffect, useState} from 'react';
import {ScrollView, StyleSheet, TouchableOpacity, View} from "react-native";
import {useTheme} from "react-native-paper";
import {FoodTable} from "./components/FoodTable";
import {FoodPoint, ProviderMenu} from "./components/model/FoodPoint";
import {RobotoText} from "../../components/utils/texts/StyledText";
import CircleIcon from "../../assets/svg/circleIcon.svg";
import {getText} from "../../locales/Locales";

const BASE_URL = 'https://appbackend.pef.czu.cz/foodpoint';

const FOOD_DAILY_OFFERS_ALL = BASE_URL + '/getMenuByDate?days=3&range=9000';
const FOOD_DAILY_OFFERS_DAILY = BASE_URL + '/getMenuByDate?days=3&range=3';

export const FoodPointScreen: React.FC = () => {

    const theme = useTheme();

    const [loading, setLoading] = useState(true);
    const [foodOffers, setFoodOffers] = useState<ProviderMenu[]>();
    const [foodProviders, setFoodProviders] = useState<string[]>();
    const [dailyOffersActive, setDailyOffersActive] = useState<boolean>();
    const [filterProvider, setFilterProvider] = useState<string[]>([]);

    useEffect(() => {
        const fetchData = async () => {

            const foodOffersUrl = dailyOffersActive ? FOOD_DAILY_OFFERS_DAILY : FOOD_DAILY_OFFERS_ALL;

            const response = await fetch(foodOffersUrl);
            const data: FoodPoint[] = await response.json();

            const providerMenu = data[0].ProviderMenu.map(s => s);
            const foodProviders = data[0].ProviderMenu.map(s => s.Provider);

            setFoodOffers(providerMenu);
            setFoodProviders(foodProviders);
            setLoading(false);
        };

        fetchData();
    }, [dailyOffersActive]);

    function getSvgColor(filters: string[], label: string) {
        const isFiltered = filters.includes(label);
        return isFiltered ? "#27AE60" : "#AE2727";
    }

    function toggleRegularAndDailyOffers() {
        setDailyOffersActive(!dailyOffersActive);
    }

    function AddOrRemoveFilter(provider: string) {
        if (!filterProvider.includes(provider)) {
            filterProvider.push(provider);
             setFilterProvider(filterProvider)
        } else {
            setFilterProvider(filterProvider.filter((item) => item !== provider));
        }
    }

    return (
            <View style={{backgroundColor: theme.colors.background, paddingBottom: 50, width: '100%', height: '100%'}}>
                <View>
                    <View style={[{backgroundColor: theme.colors.background}]}>
                        <ScrollView horizontal={true} showsHorizontalScrollIndicator={false} contentContainerStyle={styles.scrollViewPanelContainer}>
                            <TouchableOpacity onPress={() => toggleRegularAndDailyOffers()}>
                                <View style={[styles.container]}>
                                    <RobotoText
                                        style={[styles.text, {color: theme.colors.text}]}>{getText('foodPointScreen.dailyOffersLabel')}</RobotoText>
                                    <CircleIcon style={styles.icon} height={20} color={"#27AE60"} fill={"#27AE60"}
                                                stroke={"#27AE60"}/>
                                </View>
                            </TouchableOpacity>
                            { loading ? null : foodProviders.map((provider, index) =>
                                <TouchableOpacity key={index} onPress={() => AddOrRemoveFilter(provider)}>
                                    <View style={[styles.container, {

                                    }]}>
                                        <RobotoText
                                            style={[styles.text, {color: theme.colors.text}]}>{provider}</RobotoText>
                                        <CircleIcon style={styles.icon} height={20} color={getSvgColor(filterProvider, provider)} fill={getSvgColor(filterProvider, provider)}
                                                    stroke={getSvgColor(filterProvider, provider)}/>
                                    </View>
                                </TouchableOpacity>)
                            }
                        </ScrollView>
                    </View>
                </View>
                <ScrollView contentContainerStyle={{backgroundColor: theme.colors.background}}>
                    <FoodTable providerMenus={foodOffers} filterProvider={filterProvider} loading={loading}/>
                </ScrollView>
            </View>
        )
}

const styles = StyleSheet.create({
    scrollViewPanelContainer: {
        paddingVertical: 15
    },
    container: {
        height: 30,
        padding: 7,
        marginLeft: 15,
        borderWidth: 1,
        borderRadius: 6,
        flexDirection: 'row',
        alignSelf: 'flex-start'
    },
    text: {
        marginLeft: 5
    },
    icon: {
        marginRight: 7,
        marginLeft: 5,
        marginTop: -2
    }
});
