import React from "react";
import {ActivityIndicator, ImageBackground, ScrollView, StyleSheet, View} from "react-native";
import {useTheme} from "react-native-paper";
import { Table } from 'react-native-table-component';
import {getText} from "../../../locales/Locales";
import {RobotoBoldText, RobotoText} from "../../../components/utils/texts/StyledText";
import {ProviderMenu} from "./model/FoodPoint";
import {LinearGradient} from "expo-linear-gradient";

interface Props {
    providerMenus: ProviderMenu[]
    filterProvider: string[]
    loading: boolean
}

export const FoodTable: React.FC<Props> = (props: Props) => {
    const theme = useTheme();
    const isEmpty = props.providerMenus !== undefined && !props.providerMenus.length;

    return (
        isEmpty ? <NoContent /> : <View style={{backgroundColor: theme.colors.background}}>
            {props.loading ? <ActivityIndicator/> : props?.providerMenus.map((providerMenu,i) => {
                if (isFiltered(providerMenu, props.filterProvider)) return;

                return <View key={i} style={[styles.container, {backgroundColor: theme.colors.surface}]}>
                        <ImageBackground resizeMode="cover" source={require("assets/restaurantNaFarme.png")} style={styles.headerImage} imageStyle={styles.headerImage}>
                            <View style={{flex: 1, justifyContent: 'center'}}>
                                <LinearGradient style={{flex: 1, borderRadius: 20}} colors={['rgba(61,99,157,0.65)', 'rgba(52,61,99,0.65)']}>
                                    <RobotoBoldText style={[styles.textHeader, {color: '#ffffff'}] }>{providerMenu.Provider}</RobotoBoldText>
                                </LinearGradient>
                            </View>
                        </ImageBackground>
                        <View style={styles.innerContainer}>
                            <Table>
                                <View style={[styles.tableHeader, {backgroundColor: theme.colors.background}]}>
                                    <RobotoText style={{flex: 4, color: theme.colors.placeholder}}>{getText('foodPointScreen.tableHeader1')}</RobotoText>
                                    <RobotoText style={{flex: 1, color: theme.colors.placeholder}}>{getText('foodPointScreen.tableHeader2')}</RobotoText>
                                </View>
                            </Table>
                             <Table>
                                    <ScrollView contentContainerStyle={{ flexGrow: 1}}>
                                        { providerMenu.MenuList.map((menuList, index) => {
                                                return <View key={index} style={{flexDirection: 'row', borderBottomColor: theme.colors.background, borderBottomWidth: 2, padding: 10, paddingLeft: 15}}>
                                                    <View style={{flexDirection: 'column', flex: 4}}>
                                                        <RobotoText style={{color: theme.colors.text}}>{menuList.Name}</RobotoText>
                                                    </View>
                                                    <View style={{flexDirection: 'row', flex: 1}}>
                                                        <RobotoBoldText style={{color: 'green'}}>{menuList.StudentPrice}</RobotoBoldText>
                                                        <RobotoText style={{color: theme.colors.text}}> /</RobotoText>
                                                        <RobotoText style={{color: theme.colors.text}}>{menuList.FullPrice}</RobotoText>
                                                    </View>
                                                </View>
                                            })
                                        }
                                    </ScrollView>
                                </Table>
                            </View>
                    </View>
                })
            }
        </View>
    );
}

const NoContent = () => {
    const theme = useTheme();

    return(
        <View style={styles.noContentContainer}>
            <RobotoBoldText style={{backgroundColor: theme.colors.background, color: theme.colors.text}}>{getText('foodPointScreen.noDailyOffers')}</RobotoBoldText>
        </View>);
}

function isFiltered(providerMenu: ProviderMenu, filters: string[]): boolean {
    return filters.includes(providerMenu.Provider);
}

const styles = StyleSheet.create({
    tableHeader: {
        height: 30,
        paddingLeft: 5,
        flexDirection: 'row',
        alignItems: 'center',
        marginBottom: 10,
        backgroundColor: '#6F7BD9'
    },
    container: {
        borderTopLeftRadius: 20,
        borderTopRightRadius: 20,
        margin: 15,
        width: 329,
        alignSelf: "center",
        resizeMode: "contain",
        borderRadius: 16,
        height: 'auto',
        backgroundColor: 'rgba(159,33,33,0.5)',
    },
    noContentContainer: {
        margin: 15,
        alignSelf: "center",
        alignItems: "center",
        height: 'auto'
    },
    innerContainer: {
        flex: 1,
        height: 'auto'
    },
    headerImage: {
        borderTopLeftRadius: 20,
        borderTopRightRadius: 20,
        height: 90,
        width: '100%',
        resizeMode: 'cover'
    },
    row: {
        flexDirection: 'row'
    },
    textHeader: {
        marginLeft: 10,
        marginTop: 20,
        alignSelf: 'flex-start',
        fontSize: 18,
    },
});
