import React from "react";
import {
    Dimensions,
    Modal,
    ScrollView,
    StatusBar,
    StyleSheet,
    TouchableOpacity,
    View,
    TouchableWithoutFeedback,
    Image,
    LayoutAnimation,
} from "react-native";
import {RobotoText} from "components/utils/texts/StyledText";
import {appColor} from "constants/Colors";
import {AppModules} from "navigation/Screens";
import {useNavigation} from "@react-navigation/native";
import {StackNavigationProp} from "@react-navigation/stack";
import {CardItem} from "components/library/CardItem";
import {ProfileCard} from "components/library/ProfileCard";
import {CustomButton} from "components/library/CustomButton";
import {CardSettingsItem} from "components/library/CardSettingsItem";
import {CustomInput} from "components/library/CustomInput";
import {RobotoBoldText} from "components/utils/texts/StyledText";
import {getText} from "../locales/Locales";
import DarkModeIcon from "assets/svg/moonLight.svg";
import LightModeIcon from "assets/svg/moonDark.svg";
import {useTheme} from "react-native-paper";
import {PreferencesContext} from "../context/PrefferencesContext";
import NavigationArrowIcon from 'assets/svg/navigationArrowIcon.svg';
import ContactsIcon from 'assets/svg/contactsIcon.svg';

const FAB_SIZE = 56;
const {width: WINDOW_WIDTH} = Dimensions.get('window');

interface Props {
    navigation: any
}

interface State {
    profileVisible: boolean,
    firstStepsVisible: boolean,
    modalVisible: boolean,
    alephVisible: boolean,
    jobsPefVisible: boolean,
    xnameValid: boolean,
    passwordValid: boolean,
    xname: string,
    password: string,
    settingsVisible: boolean,
    darkMode: boolean
    foodPointVisible: boolean
}

export interface ShortCut {
    label: string;
    contentColor: string;
    icon: JSX.Element
    target: string
}

export const HomeScreen: React.FC<Props> = () => {

    const navigation = useNavigation<StackNavigationProp<any>>();

    const theme = useTheme();
    const { toggleTheme } = React.useContext(PreferencesContext);

    const firstStepsShortCuts: ShortCut[] = [
        { "label": getText('homeScreen.firstStepsCard.shortCutLabel.navigation'), "contentColor": "#0BCE83", "icon": <NavigationArrowIcon height={15} width={15}/>, "target": 'https://jsemprvak.pef.czu.cz/plan-arealu' },
        { "label": getText('homeScreen.firstStepsCard.shortCutLabel.contacts'), "contentColor": "#387FE9", "icon": <ContactsIcon height={15} width={15}/>, "target": 'https://www.pef.czu.cz/cs/r-7008-studium/r-7025-studijni-oddeleni'}
    ];

    const [ state, setState ] = React.useState<State>({
        profileVisible: true,
        firstStepsVisible: false,
        modalVisible: false,
        alephVisible: true,
        jobsPefVisible: true,
        xname: "",
        password: "",
        xnameValid: null,
        passwordValid: null,
        settingsVisible: false,
        darkMode: false,
        foodPointVisible: true
    });

    const themeIcon = (): JSX.Element => {
        return state.darkMode ?
                <DarkModeIcon height={styles.themeIconSize.height} width={styles.themeIconSize.width}/>
            :
            <LightModeIcon height={styles.themeIconSize.height} width={styles.themeIconSize.height}/>;
    }

    const themeStatusBar = (): JSX.Element => {
        return state.darkMode ?
            <StatusBar barStyle="light-content"/>
            :
            <StatusBar barStyle="dark-content"/>;
    }

    const renderSettingsIcon = () => {
        const imgSource = state.settingsVisible? require('assets/canceIcon.png') : require('assets/addIcon.png');
        return (
            <Image
                source={imgSource}
                style={{flex:1, height: 23, tintColor: theme.colors.text}}
                resizeMode="contain"
            />
        )
    };

    const changeSettingsLayout = () => {
        LayoutAnimation.configureNext(LayoutAnimation.Presets.easeInEaseOut);
        setState({...state, settingsVisible: !state.settingsVisible});
    };

    const changeAppSettingsLayout = () => {
        toggleTheme();
        LayoutAnimation.configureNext(LayoutAnimation.Presets.easeInEaseOut);
        setState({...state, darkMode: !state.darkMode});
    };

    const getFirstStepsResponse = (result) => {
        setState({...state, firstStepsVisible: !result});
    }
    const getAlephResponse = (result) => {
        setState({...state, alephVisible: !result});
    }
    const getFoodPointResponse = (result) => {
        setState({...state, foodPointVisible: !result});
    }
    const getJobsPefResponse = (result) => {
        setState({...state, jobsPefVisible: !result});
    }
    const getXnameValue = (result) => {
        setState({...state, xname: result});
    }
    const getPasswordValue = (result) => {
        setState({...state, password: result});
    }

    // @ts-ignore
    return (
        <View style={styles.container}>
            {themeStatusBar()}
            <ScrollView
                style={[styles.scrollView, {opacity: state.modalVisible ? 0.85 : 1, backgroundColor: theme.colors.background}]}
                contentContainerStyle={[styles.scrollViewContent, {paddingBottom: FAB_SIZE * 2}]}>
                {state.profileVisible && <ProfileCard
                    title={getText("homeScreen.profileCard.statusLoggedOut")}
                    description={getText("homeScreen.profileCard.actionStatus")}
                    balance={getText("homeScreen.profileCard.emptyBalance")}
                    balanceDescription={getText("homeScreen.profileCard.cardBalanceDescription")}
                    setState={setState}
                    state={state}
                    visible={true}
                />}

                <View style={{ maxHeight: 91, marginTop: 5, marginBottom: state.settingsVisible ? 50 : 5}}>
                    <View style={styles.cardSettingsMenu}>
                        <RobotoBoldText style={{flex:6, fontSize: 16, lineHeight: 23, color: theme.colors.text}}>{getText("homeScreen.homeScreenTitle")}</RobotoBoldText>
                        <TouchableWithoutFeedback onPress={() => changeSettingsLayout()}>
                            {renderSettingsIcon()}
                        </TouchableWithoutFeedback>
                        <TouchableOpacity onPress={() => changeAppSettingsLayout()}>
                            {themeIcon()}
                        </TouchableOpacity>
                    </View>
                    <View style={{ height: state.settingsVisible ? null : 0, overflow: 'hidden' }}>
                        <ScrollView style={[styles.cardSettingsScrollView, {backgroundColor: theme.colors.background, borderBottomColor: theme.colors.background, borderTopColor: theme.colors.background}]} horizontal={true} showsHorizontalScrollIndicator={false}>
                            <CardSettingsItem
                                title={getText("homeScreen.firstStepsCard.header")}
                                description={getText("homeScreen.firstStepsCard.exploreCampus")}
                                icon="🔍 "
                                selected={state.firstStepsVisible}
                                callback={getFirstStepsResponse.bind(this)}
                            />
                            <CardSettingsItem
                                title={getText("homeScreen.alephCard.header")}
                                description={getText("homeScreen.alephCard.notification")}
                                icon="📚 "
                                selected={state.alephVisible}
                                callback={getAlephResponse.bind(this)}
                            />
                            <CardSettingsItem
                                title={getText("homeScreen.foodCard.header")}
                                description={getText("homeScreen.foodCard.runGuide")}
                                icon="🍕 "
                                selected={state.foodPointVisible}
                                callback={getFoodPointResponse.bind(this)}
                            />
                            <CardSettingsItem
                                title={getText("homeScreen.jobsPefCard.header")}
                                description={getText("homeScreen.jobsPefCard.runGuide")}
                                icon="💼 "
                                selected={state.jobsPefVisible}
                                callback={getJobsPefResponse.bind(this)}
                            />
                        </ScrollView>
                    </View>
                </View>

                {state.firstStepsVisible && <CardItem
                    title={getText("homeScreen.firstStepsCard.header")}
                    description={getText("homeScreen.firstStepsCard.exploreCampus")}
                    imagePath={require("../assets/images/jsemPrvakCard.png")}
                    navigation={navigation}
                    target={AppModules.FIRST_STEPS}
                    shortCuts={firstStepsShortCuts}/>}

                {state.alephVisible && <CardItem
                    title={getText("homeScreen.alephCard.header")}
                    description={getText("homeScreen.alephCard.notification")}
                    imagePath={require("assets/images/alephCard.png")}
                    navigation={navigation}
                    target={AppModules.LIBRARY_LOGIN}
                    shortCuts={null}
                    tabBarShortCutTarget={AppModules.LIBRARY}
                />}
                {state.jobsPefVisible && <CardItem
                    title={getText("homeScreen.jobsPefCard.header")}
                    description={getText("homeScreen.jobsPefCard.runGuide")}
                    imagePath={require("assets/images/pefjobsCard.png")}
                    navigation={navigation}
                    target={AppModules.JOBSPEF}
                    shortCuts={null}
                />}
                {state.foodPointVisible && <CardItem
                    title={getText("homeScreen.foodCard.header")}
                    description={getText("homeScreen.foodCard.runGuide")}
                    imagePath={require("assets/images/foodPointCard.png")}
                    navigation={navigation}
                    target={AppModules.FOODPOINT}
                    shortCuts={null}
                />}
                <View style={{ height: 0 }}>
                    <Modal visible={state.modalVisible}
                           animationType="slide"
                           transparent={true}>
                        <TouchableOpacity onPress={() => setState({...state, modalVisible: false})} style={{
                            width: '100%',
                            height: '35%'
                        }}/>
                        <TouchableWithoutFeedback
                            onPressOut={(e) => {
                                if (e.nativeEvent.locationY < 50) {
                                    setState({...state, modalVisible: false})
                                }}
                            }>
                            <View style={[styles.loginBar, {backgroundColor: theme.colors.background}]}>
                                <View style={{height: 3, width: 26, backgroundColor: theme.colors.background, position: 'absolute', top: 11}}/>
                                <RobotoText style={[styles.loginBarInfo, {color: theme.colors.text}]}>{getText("homeScreen.loginBar.info")}</RobotoText>
                                <CustomInput
                                    label={getText("homeScreen.loginBar.name")}
                                    setState={setState}
                                    state={state}
                                    value={"xname"}
                                    callback={getXnameValue.bind(this)}
                                />
                                <CustomInput
                                    label={getText("homeScreen.loginBar.password")}
                                    secureTextEntry={true}
                                    setState={setState}
                                    state={state}
                                    callback={getPasswordValue.bind(this)}
                                />
                                <CustomButton
                                    title={getText("homeScreen.loginBar.actionText")}
                                    onPress={() => {
                                            setState({...state, modalVisible: false})
                                            console.log("xname: " + state.xname + " password: " + state.password)
                                        }
                                    }>
                                </CustomButton>
                            </View>
                        </TouchableWithoutFeedback>
                    </Modal>
                </View>
            </ScrollView>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        color: "#090C1A"
    },
    scrollView: {
        flex: 1,
        width: "100%"
    },
    scrollViewContent: {
        alignItems: "center",
        marginTop: 20,
    },
    loginBar:{
        backgroundColor: appColor.white,
        width: '100%',
        justifyContent: 'center',
        alignItems: 'center',
        flex: 5,
        borderTopLeftRadius: 20,
        borderTopRightRadius: 20,
    },
    loginBarInfo:{
        paddingLeft: 45,
        paddingRight: 45,
        paddingBottom: 25,
        position: 'relative',
        top: 0,
        textAlign: 'center',
        color: appColor.gray,
        fontSize: 14,
    },
    cardSettingsMenu: {
        justifyContent: 'center',
        alignItems: 'center',
        width: WINDOW_WIDTH - 40,
        flexDirection: "row",
        margin: 10,
        marginLeft: 20,
        marginRight: 20,
    },
    cardSettingsScrollView: {
        backgroundColor: appColor.white,
        borderBottomWidth: 3,
        borderBottomColor: '#EDEDED',
        borderTopWidth: 3,
        borderTopColor: '#EDEDED',
    },
    themeIconSize: {
        width: 15,
        height: 15
    },
});
